﻿using HardwareShopContracts.BindingModels;
using HardwareShopContracts.ViewModels;
using HardwareShopDatabaseImplement.Models.ManyToMany;
using HardwareShopDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace HardwareShopDatabaseImplement.Models.Storekeeper
{
    public class Component : IComponentModel
    {
        public int Id { get; set; }

        [Required]
        public string ComponentName { get; set; } = string.Empty;

        [Required]
        public double Cost { get; set; }

        [Required]
        public int UserId { get; set; }

        [ForeignKey("ComponentId")]
        public virtual List<GoodComponent> SushiComponents { get; set; } = new();

        public virtual User User { get; set; } = null!;

        public static Component? Create(ComponentBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Component()
            {
                Id = model.Id,
                ComponentName = model.ComponentName,
                Cost = model.Cost,
                UserId = model.UserId
            };
        }

        public void Update(ComponentBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            ComponentName = model.ComponentName;
            Cost = model.Cost;
        }

        public ComponentViewModel GetViewModel => new()
        {
            Id = Id,
            ComponentName = ComponentName,
            Cost = Cost,
            UserId = UserId,
            UserLogin = User.Login
        };
    }
}
